#
# spec file for package python-pynitrokey
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-pynitrokey
Version:        0.6.0
Release:        1.1
Summary:        Python Library for Nitrokey devices
License:        Apache-2.0 OR MIT
URL:            https://github.com/Nitrokey/pynitrokey
Source:         https://files.pythonhosted.org/packages/source/p/pynitrokey/pynitrokey-%{version}.tar.gz
Source1:        LICENSE-MIT
Source2:        LICENSE-APACHE
BuildRequires:  %{python_module certifi >= 14.5.14}
BuildRequires:  %{python_module cffi}
BuildRequires:  %{python_module click >= 8.1.6}
BuildRequires:  %{python_module click-aliases}
BuildRequires:  %{python_module cryptography >= 41.0.4 with %python-cryptography < 44}
BuildRequires:  %{python_module ecdsa}
BuildRequires:  %{python_module fido2 >= 1.1.0 with %python-fido2 < 2}
BuildRequires:  %{python_module flit}
BuildRequires:  %{python_module frozendict >= 2.3.4}
BuildRequires:  %{python_module nethsm >= 1.2.1 with %python-nethsm < 2}
BuildRequires:  %{python_module nitrokey}
BuildRequires:  %{python_module nkdfu}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module protobuf >= 3.17.3}
BuildRequires:  %{python_module pyserial}
BuildRequires:  %{python_module python-dateutil >= 2.7.0}
BuildRequires:  %{python_module pyusb}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module semver}
BuildRequires:  %{python_module spsdk >= 2.0 with %python-spsdk < 2.2}
BuildRequires:  %{python_module tlv8}
BuildRequires:  %{python_module tqdm}
BuildRequires:  %{python_module typing_extensions >= 4.3.0}
BuildRequires:  fdupes
BuildRequires:  intelhex
BuildRequires:  python-rpm-macros
# SECTION test
BuildRequires:  %{python_module pytest}
# /SECTION
Requires:       intelhex
Requires:       python-certifi >= 14.5.14
Requires:       python-cffi
Requires:       python-click >= 8.1.6
Requires:       python-click-aliases
Requires:       python-cryptography
Requires:       python-ecdsa
Requires:       python-frozendict >= 2.3.4
Requires:       python-nitrokey
Requires:       python-nkdfu
Requires:       python-protobuf >= 3.17.3
Requires:       python-pyserial
Requires:       python-python-dateutil >= 2.7.0
Requires:       python-pyusb
Requires:       python-requests
Requires:       python-semver
Requires:       python-tlv8
Requires:       python-tqdm
Requires:       python-typing_extensions >= 4.3.0
Requires:       python-urllib3 >= 1.26.7
Requires:       (python-fido2 >= 1.1.0 with python-fido2 < 2)
Requires:       (python-nethsm >= 1.2.1 with python-nethsm < 2)
Requires:       (python-spsdk >= 2.0 with python-spsdk < 2.2)
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
Provides:       nitropy = %{version}-%{release}
%python_subpackages

%description
# nitropy

A command line interface for the Nitrokey FIDO2, Nitrokey Start, Nitrokey 3 and
NetHSM.

## Quickstart

```
$ nitropy --help
```

## Documentation

The user documentation for the `nitropy` CLI is available on [docs.nitrokey.com](https://docs.nitrokey.com/software/nitropy/index.html). See also the product documentation for more information on the available commands:
- [Nitrokey 3](https://docs.nitrokey.com/nitrokey3/index.html)
- [Nitrokey FIDO2](https://docs.nitrokey.com/fido2/index.html)
- [Nitrokey Start](https://docs.nitrokey.com/start/index.html)
- [NetHSM](https://docs.nitrokey.com/nethsm/index.html)

%prep
%autosetup -p1 -n pynitrokey-%{version}

cp %SOURCE1 .
cp %SOURCE2 .

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/nitropy
# make scripts in start executable
%python_expand find %{buildroot}%{$python_sitelib}/pynitrokey/start/ -type f -name "*.py" -exec sed -i '1 i\#!/usr/bin/python%{$python_version}' {} +
%python_expand find %{buildroot}%{$python_sitelib}/pynitrokey/start/ -type f -name "*.py" -exec chmod 755 {} +
# remove shebangs
%python_expand find %{buildroot}%{$python_sitelib} -iname "*.py" -exec sed -i '1{/env python/d;}' {} +
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
echo "Disabled pytest"

%post
%python_install_alternative nitropy

%postun
%python_uninstall_alternative nitropy

%files %{python_files}
%doc README.md
%license LICENSE-MIT LICENSE-APACHE
%{python_sitelib}/pynitrokey/
%{python_sitelib}/pynitrokey-%{version}*-info
%python_alternative %{_bindir}/nitropy

%changelog
* Sun Nov 10 2024 Dirk Müller <dmueller@suse.com>
- update to 0.6.0:
  * Add PIV commands
  * Update prompt to more meaningful texts
- update to 0.5.0:
  * Use Nitrokey Python SDK
  * Remove spsdk from module list for version logging
* Thu Aug  1 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.4.50:
  * nethsm: Improve namespace handling in add-user by
    @robin-nitrokey in #555
  * And random generator and config failures to init status bytes
    by @sosthene-nitrokey in #556
  * Require authentication for partial restore by @mmerklinger in
    [#554]
* Wed Jul 17 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.4.49:
  * nethsm: Add support for namespaces by @robin-nitrokey in #535
* Sat Jul 13 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.4.48:
  * nethsm: Improve base64 handling and add key import from PEM by
    @robin-nitrokey in #539
  * fido2: Add get-info subcommand by @robin-nitrokey in #545
  * nk3/update: add pre_bootloader_hint for update process by
    @daringer in #546
* Thu Apr 18 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.4.47 (includes a fix for boo#1222090):
  * Patch oscrypto for linux binary by @mmerklinger in #518
  * Bump pyinstaller version by @mmerklinger in #520
  * Add common short version for help of CLI by @anotherbridge in
    [#509]
  * factory-reset(-app): remove --experimental flag by
    @sosthene-nitrokey in #529
  * fix: improve forwards compatibility with spsdk 2.1+ by @kmohrf
    in #524
  * Support spsdk 2.1 by @robin-nitrokey in #533
- remove ExclusiveArch to not only build on x86_64 (thanks to
  Guillaume Gardet for his SR)
* Tue Mar 26 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.4.46:
  * Update spsdk to v2.0 by @daringer #499
  * Add support for nkpk subcommand by @robin-nitrokey #500, #501,
    [#502], #505
  * FIDO add support for Pin protocol v2 by @daringer #507
- remove patch support-spsdk-2.0.patch as this was included
  upstream (https://github.com/Nitrokey/pynitrokey/pull/499)
* Wed Jan 31 2024 Dirk Müller <dmueller@suse.com>
- add support-spsdk-2.0.patch: support spsdk 2.0
* Mon Jan 29 2024 Dirk Müller <dmueller@suse.com>
- allow the fixed click version as well
- correct runtime requires
* Fri Jan 26 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.4.45:
  * Remove firmware version check for SE050 test by
    @sosthene-nitrokey in #481
  * nk3 secrets: Log payload length by @robin-nitrokey in #496
* Fri Jan  5 2024 Dirk Müller <dmueller@suse.com>
- update to 0.4.44:
  * This release updates the `nk3 set-config` command for the
    upcoming Nitrokey 3 test firmware release.
  * nk3 set-config: Add support for opcard.use_se050_backend
  * **Full Changelog**: https://github.com/Nitrokey/pynitrokey/co
    mpare/v0.4.43...v0.4.44
* Thu Nov 30 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.4.43:
  This release improves the UI of some NetHSM commands, introduces
  the experimental `nk3 factory-reset` command and adds a warning
  to nk3 set-config when used with unknown config keys.
  * Changelog
  - nethsm: Fix table formatting in list-keys by @robin-nitrokey
    in https://github.com/Nitrokey/pynitrokey/pull/476
  - Display value for type and mechanism on NetHSM get_key by
    @mmerklinger in
    https://github.com/Nitrokey/pynitrokey/pull/478
  - Update nethsm to v1.0.0 by @robin-nitrokey in
    https://github.com/Nitrokey/pynitrokey/pull/477
  - Add support for full device factory reset command by
    @sosthene-nitrokey in
    https://github.com/Nitrokey/pynitrokey/pull/472
  - nk3 set-config: Add warning and confirmation prompt by
    @robin-nitrokey in
    https://github.com/Nitrokey/pynitrokey/pull/479
* Mon Nov 27 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.4.42:
  * fido2 make-credential: Clenaup and add rk and uv options by
    @robin-nitrokey in
    https://github.com/Nitrokey/pynitrokey/pull/464
  * Remove frozendict dependency by @mmerklinger in
    https://github.com/Nitrokey/pynitrokey/pull/466
  * nk3: Support build component in version string by
    @robin-nitrokey in
    https://github.com/Nitrokey/pynitrokey/pull/474
  * Update nethsm dependency by @robin-nitrokey in
    https://github.com/Nitrokey/pynitrokey/pull/469
* Wed Nov  8 2023 Matej Cepl <mcepl@suse.com>
- Fix a bad Requires: with %%{python_module construct.
* Thu Nov  2 2023 Johannes Kastl <kastl@b1-systems.de>
- clarify licensing, as this is dual-licensed with MIT and
  Apache-2.0
- Marcus added both licenses
* Mon Oct 30 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.4.41:
  * nk3
  - Add the `SE50_ERROR` flag to the init status
    (https://github.com/Nitrokey/pynitrokey/pull/436)
  - Add the SE050 tests to `nk3 test` if supported
    (https://github.com/Nitrokey/pynitrokey/pull/423)
  - Add `get-config` and `set-config` commands
    (https://github.com/Nitrokey/pynitrokey/pull/448)
  * nethsm
  - Move the NetHSM API into a separate `nethsm` package, see
    https://github.com/Nitrokey/nethsm-sdk-py
    (https://github.com/Nitrokey/pynitrokey/pull/450)
  - Validate the backup file in `backup` and `restore` and add
    the `validate-backup` and `restore-backup` commands
    (https://github.com/Nitrokey/pynitrokey/pull/457)
  * maintenance
  - Update fido2, cryptography, spsdk dependencies
    (https://github.com/Nitrokey/pynitrokey/pull/449)
- include LICENSE-MIT and LICENSE-APACHE files from older release,
  as these were removed.
* Wed Sep 27 2023 Lars Vogdt <lars@linux-schulserver.de>
- update to 0.4.40:
  * nethsm: Various updates and improvements (#435, #437, #439,
    [#445])
  * nk3: Fix "generator didn't stop" update error for LPC55 devices
    (#394)
  * nk3 secrets: Add support for updating credentials (#424, #425,
    [#428])
  * nk3 test: Don’t show touch prompt if PIN is missing (#411)
  * Update urllib3 (#426)
- update to 0.4.39:
  * Improved logging (#399, @Laborratte5)
  * Cleanup, refactoring and fixes of the fido2 module (#337, #410)
  * Check pynitrokey version on firmware update (#416,
    @Laborratte5)
  * Update dependencies to fix vulnerabilities and installation
    problems (#364)
- update to 0.4.38:
  Secrets App updates: add Password Safe, challenge-response, and
  improve UI
  * Implemented enhancements:
  - Secrets App Password Safe support for Nitrokey 3 #380
    (szszszsz)
  * Fixed bugs:
  - Firmware 1.3.1 update failed for nk3 #368
  * Closed issues:
  - nitropy list errors out due to deepmerge not being found (in
    a version recent enough) #396
  - Secrets App: improve UI/UX for Password Safe support #392
- update to 0.4.37:
  * Features
  - nk3 status: Add variant (#376)
  - nk3 secrets: Update Secrets App API (#377)
  - Add py.typed file (#387)
  * Bugfixes
  - nk3 test: Fix provisioner test (#367)
  - fido2 list-credentials: Handle missing RP name (#359)
  - fido2 list-credentials: Skip enumerating RPs when empty
    (#360)
- remove outdated dependency to deepmerge
- explicitly require click-aliases and semver
- build as noarch, as suggested by rpmlint
* Mon Jul  3 2023 Johannes Kastl <kastl@b1-systems.de>
- new package python-pynitrokey: Python client for managing Nitrokey devices
